@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-# $Id: setup.py 10301 2017-09-17 08:17:11Z Lavender $
+# $Id: setup.py 10314 2017-09-24 09:37:54Z Lavender $
 #
 # Copyright (c) 2017 Nuwa Information Co., Ltd, All Rights Reserved.
 #
@@ -12,8 +12,8 @@
 # limitations under the License.
 #
 # $Author: Lavender $
-# $Date: 2017-09-17 16:17:11 +0800 (週日, 17 九月 2017) $
-# $Revision: 10301 $ 
+# $Date: 2017-09-24 17:37:54 +0800 (週日, 24 九月 2017) $
+# $Revision: 10314 $ 
 
 import os
 import sys
@@ -62,10 +62,10 @@ def copyToPath(baseDir, templateDir, staticDir, mode):
                 continue
             origin = os.path.join(root, f)
             
-            if "static" in root:
+            if os.path.join(SETUP_DIR, "static") in root:
                 index = len(os.path.join(SETUP_DIR, "static")) + 1
                 dst = os.path.join(staticDir, origin[index:])
-            elif "templates" in root:
+            elif os.path.join(SETUP_DIR, "templates") in root:
                 result = os.path.splitext(origin)[0]
                 if mode == 'programmer':
                     if result.endswith("_user"):
@@ -76,12 +76,11 @@ def copyToPath(baseDir, templateDir, staticDir, mode):
                         continue
                     dst = os.path.join(
                         templateDir, f.replace('_user.html', '.html'))
-            elif "fixtures" in root:
+            elif os.path.join(SETUP_DIR, "fixtures") in root:
                 index = len(os.path.join(SETUP_DIR, "fixtures")) + 1
                 dst = os.path.join(baseDir, "fixtures", origin[index:])
             else:
-                dst = os.path.join(baseDir, f)
-                
+                continue
             
             if os.path.isfile(dst):
                 logger.error("%s is exist. failed to copy file." % dst)
@@ -95,6 +94,7 @@ def findSettings(path):
         for f in files:
             if f == 'settings.py':
                 return os.path.join(root, f)
+    return None
                 
 def writeSettings(settingsPath, templateDir, staticDir, hasCmsTemplate):
     logger.info("-----Start write and backup settings.py-----")
@@ -153,18 +153,20 @@ if DEBUG:
         os.path.join(BASE_DIR, 'static'),
     )
 else:
-    STATIC_ROOT = os.path.join(
-        os.path.dirname(os.path.dirname(__file__)), 'static')
+    STATIC_ROOT = os.path.join(BASE_DIR, 'static')
 '''
         
         settings.write(content)
     logger.info("Succeed to write settings.py")
               
 @transaction.atomic    
-def loadData(language):
+def loadData(baseDir, language):
     logger.info("-----Start load data-----")
     data = os.path.join(".", 'fixtures', 'initial_data.json')
-    os.system("%s manage.py loaddata %s" % (sys.executable, data))
+    result = os.system("%s manage.py loaddata %s" % (sys.executable, data))
+    
+    if not result == 0:
+        return False
     
     from cms.models.pagemodel import Page
     from cms.models.titlemodels import Title
@@ -175,7 +177,8 @@ def loadData(language):
     for title in Title.objects.all():
         title.language = language
         title.save()
-    
+        
+    return True
         
 
 if __name__ == "__main__":
@@ -186,27 +189,98 @@ if __name__ == "__main__":
         default='programmer',
         choices=['programmer', 'user',],
         help='programmer mode or user mode.')
+        
+    parser.add_argument(
+        '-q', '--quiet', 
+        action='store_true',
+        help="Don't run the configuration wizard, "
+             "just use the provided values.")
     
     args = parser.parse_args()
     
+    quiet = args.quiet
+
     if args.mode == 'programmer':
         mode = 'programmer'
     else:
         mode = 'user'
+        
+    path = args.path
     
-    settingsPath = findSettings(args.path)
+    settingsPath = findSettings(path)
     
-    settingModule = os.path.splitext(settingsPath[len(args.path) + 1:])[0]
+    if not settingsPath:
+        projectName = raw_input(
+            "Django project isn't found. "
+            "Auto create one by djangocms-installer. Input a project name:")
+        path = os.path.join(path, projectName)
+        
+        if quiet:
+            result = os.system("djangocms -f -p %s %s -q" % (path, projectName))
+        else:
+            result = os.system("djangocms -f -p %s %s" % (path, projectName))
+            
+        if not result == 0:
+            print
+            logger.error(
+                "Please check your environment "
+                "installed djangocms-installer or upgrade to latest.")
+            sys.exit()
+            
+        settingsPath = findSettings(path)
+    else:
+        path = os.path.dirname(os.path.dirname(settingsPath))
+    
+    settingModule = os.path.splitext(settingsPath[len(path) + 1:])[0]
     settingModule = settingModule.replace("/", ".")
     settingModule = settingModule.replace("\\", ".")
     
-    sys.path.append(args.path)
+    sys.path.append(path)
     os.environ['DJANGO_SETTINGS_MODULE'] = settingModule
     django.setup()
     
     from django.conf import settings
-    os.chdir(args.path)
     
+    baseDir = settings.BASE_DIR
+    
+    apps = [
+        'djangocms_admin_style',
+        'django.contrib.auth',
+        'django.contrib.contenttypes',
+        'django.contrib.sessions',
+        'django.contrib.admin',
+        'django.contrib.sites',
+        'django.contrib.sitemaps',
+        'django.contrib.staticfiles',
+        'django.contrib.messages',
+        'cms',
+        'menus',
+        'sekizai',
+        'treebeard',
+        'djangocms_text_ckeditor',
+        'filer',
+        'easy_thumbnails',
+        'djangocms_column',
+        'djangocms_link',
+        'cmsplugin_filer_file',
+        'cmsplugin_filer_folder',
+        'cmsplugin_filer_image',
+        'cmsplugin_filer_utils',
+        'djangocms_style',
+        'djangocms_snippet',
+        'djangocms_googlemap',
+        'djangocms_video',
+    ]
+    
+    endSetup = False
+    for app in apps:
+        if not app in settings.INSTALLED_APPS:
+            logger.error("The app doesn't include in INSTALLED_APPS: %s" % app)
+            endSetup = True
+    
+    if endSetup:
+        sys.exit()
+            
     try:
         templateDir = settings.TEMPLATES[0]['DIRS'][0]
     except Exception as e:
@@ -217,14 +291,21 @@ if __name__ == "__main__":
     except Exception as e:
         staticDir = None
     
-    copyToPath(args.path, templateDir, staticDir, mode)
+    copyToPath(baseDir, templateDir, staticDir, mode)
     
     if hasattr(settings, "CMS_TEMPLATES"):
         hasCmsTemplate = True
     else:
         hasCmsTemplate = False
         
-    writeSettings(settingsPath, templateDir, staticDir, hasCmsTemplate)
-    loadData(settings.LANGUAGE_CODE)
+    writeSettings(settingsPath, 
+        templateDir, staticDir, hasCmsTemplate)
+        
+    os.chdir(baseDir)
+        
+    success = loadData(baseDir, settings.LANGUAGE_CODE)
+    if not success:
+        print
+        logger.error("Please check the project's db was migrated.")
     
     
\ No newline at end of file
